@@ -139,8 +139,6 @@ public class Utils {
 
 			toReturn.put(replacedKey, values);
 		}
-
-
 		return toReturn;
 	}
 
@@ -197,16 +195,19 @@ public class Utils {
 
 		try(CloseableHttpClient httpClient = HttpClientBuilder.create().build();){
 
-			// if there are merges, update the status of the involved records immediately
+			// send update to the knowledge base
+			GRSFUpdaterServiceClient.updateKB(httpClient, serviceUrl, bean, catalogue, username, fullName);
+			
+			// if there are merges, update the status of the other involved records
 			if(bean.isMergesInvolved())
 				updateStatusInvolvedRecords(bean, catalogue);
 
-			// send update to the knowledge base
-			GRSFUpdaterServiceClient.updateKB(httpClient, serviceUrl, bean, catalogue, username, fullName);
-
 			// require social networking url
 			final String baseUrlSocial = SocialCommunications.getBaseUrlSocialService(httpServletRequest);
 
+			// and the user current browser url
+			final String currentBrowserUrl = Utils.getCurrentClientUrl(httpServletRequest).split("\\?")[0]; // ignore other parameters		
+
 			// manage interactions through a separated thread but set there security token and context (and then reset them)
 			Thread t = new Thread(new Runnable() {
 
@@ -217,11 +218,11 @@ public class Utils {
 					try{
 
 						// send email to Editors and Reviewers
-						SocialCommunications.sendEmailAdministratorsOnMerge(baseUrlSocial, bean, catalogue, username, fullName, 
-								groupId, httpServletRequest, bean.isMergesInvolved());
+						SocialCommunications.sendEmailAdministrators(baseUrlSocial, bean, catalogue, username, fullName, 
+								groupId, currentBrowserUrl, bean.isMergesInvolved());
 
-						// create a post about the operation
-						SocialCommunications.writeProductPost(baseUrlSocial, bean, username, fullName, false);
+						//	create a post about the operation 
+						SocialCommunications.writeProductPost(baseUrlSocial, bean, username, fullName, false, currentBrowserUrl);
 
 					}catch(Exception e){
 						logger.error("Something failed while alerting editors/reviewers", e);
@@ -255,6 +256,9 @@ public class Utils {
 		// require social networking url
 		final String baseUrlSocial = SocialCommunications.getBaseUrlSocialService(httpServletRequest);
 
+		// and the user current browser url
+		final String currentBrowserUrl = Utils.getCurrentClientUrl(httpServletRequest).split("\\?")[0]; // ignore other parameters		
+		
 		// manage interactions through a separated thread but set there security token and context (and then reset them)
 		Thread t = new Thread(new Runnable() {
 
@@ -265,7 +269,7 @@ public class Utils {
 				try{
 
 					// write post about this
-					SocialCommunications.writePostOnRevert(baseUrlSocial, rInfo, true);
+					SocialCommunications.writePostOnRevert(baseUrlSocial, rInfo, false, currentBrowserUrl);
 
 					// alert who's involved
 					SocialCommunications.sendEmailAdministratorsOnOperationReverted(baseUrlSocial, rInfo, groupId);
@@ -277,7 +281,7 @@ public class Utils {
 					SecurityTokenProvider.instance.reset();
 				}
 			}
-			
+
 		});
 		t.start();
 
@@ -298,18 +302,12 @@ public class Utils {
 		for(SimilarGRSFRecord s: bean.getSimilarGrsfRecords()){
 			if(s.isSuggestedMerge()){
 				String productId = s.getKnowledgeBaseId();
-				Map<String, List<String>> extrasMap = getExtrasAsHashMap(catalogue.getDataset(productId, sysApi).getExtras());
-				extrasMap.put(Constants.STATUS_OF_THE_GRSF_RECORD_CUSTOM_KEY, Arrays.asList(Status.To_be_Merged.getOrigName()));
-				catalogue.patchProductCustomFields(productId, sysApi, extrasMap);
+				Map<String, List<String>> updateStatus = new HashMap<String, List<String>>(1);
+				updateStatus.put(Constants.STATUS_OF_THE_GRSF_RECORD_CUSTOM_KEY, Arrays.asList(Status.To_be_Merged.getOrigName()));
+				catalogue.patchProductCustomFields(productId, sysApi, updateStatus, true);
 			}
 		}
 
-		// update the current status record
-		String productId = bean.getKnowledgeBaseId();
-		Map<String, List<String>> extrasMap = getExtrasAsHashMap(catalogue.getDataset(productId, sysApi).getExtras());
-		extrasMap.put(Constants.STATUS_OF_THE_GRSF_RECORD_CUSTOM_KEY, Arrays.asList(Status.To_be_Merged.getOrigName()));
-		catalogue.patchProductCustomFields(productId, sysApi, extrasMap);
-
 	}
 
 	/**
@@ -453,7 +451,7 @@ public class Utils {
 	 * @return {@link SimilarGRSFRecord}
 	 * @throws ParseException 
 	 */
-	public static SimilarGRSFRecord similarGRSFRecordFromJson(String json, DataCatalogue ctl, String apiKey) throws ParseException{
+	public static SimilarGRSFRecord similarGRSFRecordFromJson(String json, DataCatalogue ctl, String apiKey, HttpSession httpSession) throws ParseException{
 
 		if(json == null)
 			return null;
@@ -463,15 +461,21 @@ public class Utils {
 
 		String uuid = getDatasetKnowledgeBaseIdFromUrl((String)object.get(Constants.SIMILAR_RECORDS_BEAN_FIELD_URL));
 		CkanDataset dataset = ctl.getDataset(uuid, apiKey);
+		
+		boolean isStock = dataset.getExtrasAsHashMap().get(Constants.DOMAIN_CUSTOM_KEY).contains(Product_Type.STOCK.getOrigName());
+		Map<String, String> fieldsNamespacesMap = 
+				Utils.getFieldToFieldNameSpaceMapping(httpSession, isStock ? 
+						Constants.GENERIC_RESOURCE_NAME_MAP_KEY_NAMESPACES_STOCK : Constants.GENERIC_RESOURCE_NAME_MAP_KEY_NAMESPACES_FISHERY);
+		Map<String, List<String>> extrasWithoutNamespaces = Utils.replaceFieldsKey(dataset.getExtras(), fieldsNamespacesMap);
 
 		return new SimilarGRSFRecord(
 				uuid,
 				(String)object.get(Constants.SIMILAR_RECORDS_BEAN_FIELD_DESCRIPTION),
 				(String)object.get(Constants.SIMILAR_RECORDS_BEAN_FIELD_NAME),
-				dataset.getTitle(), // no title
+				dataset.getTitle(),
 				(String)object.get(Constants.SIMILAR_RECORDS_BEAN_FIELD_URL),
-				(String)object.get(Constants.SIMILAR_RECORDS_BEAN_FIELD_IDENTIFIER),
-				dataset.getExtrasAsHashMap().get(Constants.DOMAIN_CUSTOM_KEY)
+				extrasWithoutNamespaces.get(Constants.GRSF_SEMANTIC_IDENTIFIER_CUSTOM_KEY).get(0),
+				extrasWithoutNamespaces.get(Constants.DOMAIN_CUSTOM_KEY).get(0)
 				);
 
 	}
